******************
United (ˈjuːnɪtɪd)
******************

A SI unit representation and conversion tool.

Example:
    Creating a unit with Volt V as a numerator and Ampere A as denominator will result into the
    unit Ohm (Ω). Same goes for creating two separate units Volt and Ampere and dividing Volt by Ampere.

Features
========

* Arithmetic operations:
    * Multiplying
    * Dividing
    * Adding
    * Subtracting
    * Raising power
* Different priorities for the look up table
    * Default
    * Electric
    * Mechanic
